ProSHADE: File Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented file members with links to the documentation:

- axesToGroupTypeSanityCheck() : ProSHADE_data.cpp
- checkElementAlreadyExists() : ProSHADE_data.cpp
- checkElementsFormGroup() : ProSHADE_data.cpp
- determinePeakThreshold() : ProSHADE_symmetry.cpp
- findBestIcosDihedralPair() : ProSHADE_symmetry.cpp
- findBestOctaDihedralPair() : ProSHADE_symmetry.cpp
- findBestTetraDihedralPair() : ProSHADE_symmetry.cpp
- getReBoxedMap() : ProSHADE.cpp , ProSHADE.hpp
- sortProSHADESymmetryByPeak() : ProSHADE_symmetry.cpp